Carsten Ehbrecht <ehbrecht@dkrz.de>
Eric Lemoine <eric.lemoine@gmail.com> (http://github.com/elemoine/papyrus_ogcproxy)
David Byrns <david.byrns@crim.ca>
Francis Charette-Migneault <francis.charette-migneault@crim.ca>
